==> nextcloud-14.0.13.zip: nextcloud/apps/gallery/l10n/bs.js <==
OC.L10N.register(
    "gallery",
    {
    "Error loading slideshow template" : "Greška pri učitavanju šablona animiranog preglednika",
    "Next" : "Sljedeće",
    "Play" : "Play",
    "Pause" : "Pauza",
    "Previous" : "Prethodno",
    "Close" : "Zatvori",
    "Download" : "Preuzmi",
    "Delete" : "Obriši",
    "Share" : "Podijeli",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neispravno ime datoteke.",
    "File name cannot be empty." : "Naziv datoteke ne može biti prazan",
    "Upload" : "Učitaj",
    "Error" : "Greška",
    "Error while sharing" : "Greška pri dijeljenju",
    "Error while unsharing" : "Ggreška pri prestanku dijeljenja",
    "Error while changing permissions" : "Greška pri mijenjanju dozvola",
    "Shared with you and the group {group} by {owner}" : "Dijeljeno s vama i grupom {group} vlasnika {owner}",
    "Shared with you by {owner}" : "Podijeljeno sa vama od {owner}",
    "Share link" : "Podijelite vezu",
    "The public link will expire no later than {days} days after it is created" : "Javna veza ističe najkasnije {days} dana nakon što je kreirana",
    "Link" : "Veza",
    "Password protect" : "Zaštitita lozinkom",
    "Password" : "Lozinka",
    "Choose a password for the public link" : "Izaberite lozinku za javnu vezu",
    "Allow editing" : "Dozvolite izmjenu",
    "Email link to person" : "Pošaljite osobi vezu e-poštom",
    "Send" : "Pošalji",
    "Set expiration date" : "Postavite datum isteka",
    "Expiration" : "Istek",
    "Expiration date" : "Datum isteka",
    "Adding user..." : "Dodavanje korisnika...",
    "group" : "grupa",
    "remote" : "daljinski",
    "Resharing is not allowed" : "Ponovno dijeljenje nije dopušteno",
    "Unshare" : "Prestani  dijeliti",
    "notify by email" : "Obavijesti e-poštom",
    "can share" : "mogu dijeliti",
    "can edit" : "mogu mijenjati",
    "access control" : "Kontrola pristupa",
    "create" : "kreiraj",
    "change" : "izmjeni",
    "delete" : "izbriši",
    "Password protected" : "Zaštićeno lozinkom",
    "Error unsetting expiration date" : "Pogrešno uklanjanje postavke datuma isteka",
    "Error setting expiration date" : "Pogrešno postavljanje datuma isteka",
    "Email sent" : "E-pošta je poslana",
    "Warning" : "Upozorenje",
    "Cancel upload" : "Prekini učitavanje",
    "File list" : "Popis datoteka",
    "Picture view" : "Prikaz slika",
    "New" : "Novo"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-17.0.6.zip: nextcloud/apps/gallery/l10n/bs.js <==
OC.L10N.register(
    "gallery",
    {
    "Error loading slideshow template" : "Greška pri učitavanju šablona animiranog preglednika",
    "Next" : "Sljedeće",
    "Play" : "Play",
    "Pause" : "Pauza",
    "Previous" : "Prethodno",
    "Close" : "Zatvori",
    "Download" : "Preuzmi",
    "Delete" : "Obriši",
    "Share" : "Podijeli",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neispravno ime datoteke.",
    "File name cannot be empty." : "Naziv datoteke ne može biti prazan",
    "Upload" : "Učitaj",
    "Error" : "Greška",
    "Error while sharing" : "Greška pri dijeljenju",
    "Error while unsharing" : "Ggreška pri prestanku dijeljenja",
    "Error while changing permissions" : "Greška pri mijenjanju dozvola",
    "Shared with you and the group {group} by {owner}" : "Dijeljeno s vama i grupom {group} vlasnika {owner}",
    "Shared with you by {owner}" : "Podijeljeno sa vama od {owner}",
    "Share link" : "Podijelite vezu",
    "The public link will expire no later than {days} days after it is created" : "Javna veza ističe najkasnije {days} dana nakon što je kreirana",
    "Link" : "Veza",
    "Password protect" : "Zaštitita lozinkom",
    "Password" : "Lozinka",
    "Choose a password for the public link" : "Izaberite lozinku za javnu vezu",
    "Allow editing" : "Dozvolite izmjenu",
    "Email link to person" : "Pošaljite osobi vezu e-poštom",
    "Send" : "Pošalji",
    "Set expiration date" : "Postavite datum isteka",
    "Expiration" : "Istek",
    "Expiration date" : "Datum isteka",
    "Adding user..." : "Dodavanje korisnika...",
    "group" : "grupa",
    "remote" : "daljinski",
    "Resharing is not allowed" : "Ponovno dijeljenje nije dopušteno",
    "Unshare" : "Prestani  dijeliti",
    "notify by email" : "Obavijesti e-poštom",
    "can share" : "mogu dijeliti",
    "can edit" : "mogu mijenjati",
    "access control" : "Kontrola pristupa",
    "create" : "kreiraj",
    "change" : "izmjeni",
    "delete" : "izbriši",
    "Password protected" : "Zaštićeno lozinkom",
    "Error unsetting expiration date" : "Pogrešno uklanjanje postavke datuma isteka",
    "Error setting expiration date" : "Pogrešno postavljanje datuma isteka",
    "Email sent" : "E-pošta je poslana",
    "Warning" : "Upozorenje",
    "Cancel upload" : "Prekini učitavanje",
    "Sort by name" : "Order by name",
    "Sort by date" : "Order by date",
    "File list" : "Popis datoteka",
    "Picture view" : "Prikaz slika"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
